function activate(content) {
    let identical = {
        "web": true,
        "http": true,
        "https": true,
    };
    let config = goby.getConfiguration();
    const fs = require('fs');
    const os = require('os');
    var cp = require('child_process');
    const path = require('path');
    let vp = config.VscanPlusPATH.default;
    let command = config.Command.default;
    goby.registerCommand('VscanPlus', (content) => {
        let ipPattern = /\b(?:\d{1,3}\.){3}\d{1,3}\b/;
        let ipAddress = content.hostinfo.match(ipPattern);
        let ipStr = ipAddress[0].replace(/\./g, "-"); // 将 ipAddress 数组的第一个元素转换为字符串，并替换其中的点号
        let savePath = 'vscan_result_' + ipStr + '.json'
        console.log(vp)
        console.log(command)
        let cmd = `"${vp} -host ${ipAddress} ${command} -json -o ${savePath}"`
        cp.exec(`start cmd /K ${cmd}`);
        goby.showInformationMessage("已开始扫描,请到Goby目录下查看");

    });

    goby.registerCommand('CheckResult', () => {
        goby.getAsset(goby.getTaskId(), getJsonFilesList);
    });

    goby.registerCommand('VscanPlus_visi',  (content) => {
        if (identical[content.protocol]) return true;
        return false;
    });
}
function valid(data, files){
    let filesList = [];
    // 检查数据中是否存在ips字段
    if (data.data && data.data.ips && Array.isArray(data.data.ips)) {
        // 遍历ips数组中的每个对象
        data.data.ips.forEach(ipObj => {
            const ip = ipObj.ip; // 获取IP地址
            files.forEach((file) => {
                if ((file.replace(/[-]/g, ".")).includes(ip) && !(file.includes("port."))) {
                    // 获取文件的完整路径
                    const fullPath = path.join('./', file);
                    filesList.push(fullPath);
                }
            });
        });
        readMultipleJSONFiles(filesList);
    } else {
        return null;
    }
}
function getJsonFilesList(data) {
    // goby.showInformationMessage(data);
    var urls = [];
    // 检查是否存在ips对象
    if (data.data && data.data.ips) {
        // 遍历ips数组
        data.data.ips.forEach(function(ipObj) {
            // goby.showInformationMessage(ipObj);
            // 检查是否存在protocols对象
            if (ipObj.protocols) {
                // 遍历protocols对象的所有键
                // goby.showInformationMessage(ipObj);
                Object.keys(ipObj.protocols).forEach(function(protocolKey) {
                    // goby.showInformationMessage(protocolKey);
                    var protocolObj = ipObj.protocols[protocolKey];
                    // goby.showInformationMessage(protocolObj);
                    // 检查协议是否为 "web"、"http" 或 "https"
                    if (protocolObj.protocol === "web" || protocolObj.protocol === "http" || protocolObj.protocol === "https") {
                        // 如果 URL 不为空，则直接添加到数组
                        if (protocolObj.url !== "") {
                            urls.push(protocolObj.url);
                        } else {
                            // 如果 URL 为空，则根据协议构建 URL，并添加到数组
                            if (protocolObj.protocol === "http") {
                                urls.push("http://" + protocolKey.split(":")[0] + ":" + protocolObj.port);
                            } else if (protocolObj.protocol === "https") {
                                urls.push("https://" + protocolKey.split(":")[0] + ":" + protocolObj.port);
                            }
                        }
                    }
                });
            }
        });
    } else {
        console.log("JSON数据中不存在ips对象或数据结构错误。");
    }
    goby.showInformationMessage(urls);
    let directoryPath = './';
    try {
        // 检查目录是否存在
        if (fs.existsSync(directoryPath)) {
            // 读取目录中的所有文件
            const files = fs.readdirSync(directoryPath);
            const filesList = valid(data,files);
            if (filesList.length > 0) {
                return filesList;
            } else {
                return null; // 如果文件列表为空，返回 null
            }
        } else {
            console.error(`Directory does not exist: ${directoryPath}`);
            goby.showInformationMessage(`Directory does not exist: ${directoryPath}`);
            return null;
        }
    } catch (err) {
        console.error('Error reading directory:', err);
        return null
    }
}

function readMultipleJSONFiles(fileList) {
    let allTargets = []; // 保存所有文件中的目标数组

    // 遍历文件列表
    fileList.forEach(filePath => {
        // 读取并处理单个文件的内容
        const targets = readJSONLinesFromFile(filePath);
        if (targets) {
            // 将当前文件中的目标数组合并到所有目标数组中
            allTargets = allTargets.concat(targets);
        }
    });

    // 将合并后的所有目标数组传递给 HTML 页面
    const reportURL = path.join(__dirname, '/vReport.html?targets=' + encodeURIComponent(JSON.stringify(allTargets)));
    // 显示报告页面
    goby.showIframeDia(reportURL, "VscanPlus_Report", "960", "500");
}

function readJSONLinesFromFile(filePath) {
    try {
        // 读取文件内容
        const fileContents = fs.readFileSync(filePath, 'utf8');
        // 将文件内容按行分割
        const lines = fileContents.split('\n');
        let targets = [];
        // 遍历每一行
        lines.forEach(line => {
            if (line.trim()) { // 确保非空行
                const jsonObject = JSON.parse(line); // 解析每行的 JSON 数据
                targets.push({
                    url: jsonObject.url || '',
                    fileFuzz: jsonObject['file-fuzz'] || '',
                    technologies: jsonObject.technologies || '',
                    POC: jsonObject.POC || ''
                });
            }
        });
        
        // 返回目标数组
        return targets;
    } catch (err) {
        console.error('Error reading JSON Lines from file:', err);
        console.error('File path:', filePath); // 打印出错的文件路径
        return null; // 返回 null 表示处理失败
    }
}

exports.activate = activate;